@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	@(#) mhmimetypes.pl 1.4 00/01/15 17:54:32
+##	@(#) mhmimetypes.pl 1.6 01/06/10 17:37:44
 ##  Author:
 ##      Earl Hood       mhonarc@pobox.com
 ##  Description:
@@ -43,6 +43,9 @@ $UnknownExt     = 'bin';
     'application/mathematica', 		'ma:Mathematica Notebook document',
     'application/mbedlet',		'mbd:mbedlet file',
     'application/msword',		'doc:MS-Word document',
+    'application/ms-excel',            	'xls:MS-Excel spreadsheet',
+    'application/ms-powerpoint',	'ppt:MS-Powerpoint presentation',
+    'application/ms-project',		'mpp:MS-Project file',
     'application/octet-stream', 	'bin:Binary data',
     'application/oda', 			'oda:ODA file',
     'application/pdf', 			'pdf:Adobe PDF document',
@@ -252,12 +255,14 @@ sub get_mime_ext {
 ##	to a file.
 ##
 sub write_attachment {
-    my $ctype	= lc shift;
+    my $content	= lc shift;
     my $sref	= shift;
     my $path	= shift;
     my $fname	= shift;
     my $inext	= shift;
-    my($cnt, $pre, $ext, $pathname);
+    my($ctype, $cnt, $pre, $ext, $pathname);
+
+    ($ctype) = $content =~ m%^\s*([\w-\./]+)%;	# Extract content-type
 
     local(*OUTFILE);
 
@@ -281,7 +286,7 @@ sub write_attachment {
     $pathname .= $DIRSEP . $fname;
 
     if (open(OUTFILE, "> $pathname")) {
-	binmode(OUTFILE);		# For MS-DOS
+	binmode(OUTFILE);		# For WinDog
 	print OUTFILE $$sref;
 	close(OUTFILE);
     } else {
