@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	@(#) mhrcfile.pl 2.14 01/04/10 21:36:41
+##	@(#) mhrcfile.pl 2.15 01/06/10 17:39:12
 ##  Author:
 ##      Earl Hood       mhonarc@pobox.com
 ##  Description:
@@ -477,6 +477,15 @@ sub read_resource_file {
 	    }
 	    last FMTSW;
 	}
+	if ($elem eq 'mimeexcs') {		# Mime exclusions
+	    %readmail::MIMEExcs = ()  if $override;
+	    while (defined($line = <$handle>)) {
+		last  if $line =~ /^\s*<\/mimeexcs\s*>/i;
+		$line =~ s/\s//g;  $line =~ tr/A-Z/a-z/;
+		$readmail::MIMEExcs{$line} = 1  if $line;
+	    }
+	    last FMTSW;
+	}
 	if ($elem eq "months") {		# Full month names
 	    @a = &get_list_content($handle, $elem);
 	    if (scalar(@a)) {
